==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiGui/QTextBlockUserData_shell.cpp <==
#include "QTextBlockUserData_shell.h"
#include <QtJambi/Cast>

void deleter_QTextBlockUserData(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTextBlockUserData")
    QTextBlockUserData *_ptr = reinterpret_cast<QTextBlockUserData *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QTextBlockUserData_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QTextBlockUserData_shell) ); }

jmethodID QTextBlockUserData_shell::__shell_javaMethod(int pos) const { return QTextBlockUserData_shell::__shell()->javaMethod(typeid(QTextBlockUserData), pos); }

// emitting (writeShellConstructor)
QTextBlockUserData_shell::QTextBlockUserData_shell()
    : QTextBlockUserData()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QTextBlockUserData::QTextBlockUserData_shell()", QTextBlockUserData_shell::__shell())
    QTextBlockUserData_shell::__shell()->constructed(typeid(QTextBlockUserData));
}

// emitting (writeShellDestructor)
QTextBlockUserData_shell::~QTextBlockUserData_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QTextBlockUserData::~QTextBlockUserData()", QTextBlockUserData_shell::__shell())
    QTextBlockUserData_shell::__shell()->destructed(typeid(QTextBlockUserData));
}

void QTextBlockUserData_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QTextBlockUserData_shell*>(ptr)->QTextBlockUserData_shell::__shell()->tryDeleteShell(typeid(QTextBlockUserData));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new 
void __qt_construct_QTextBlockUserData_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QTextBlockUserData *__qt_this = new(__qtjambi_ptr) QTextBlockUserData_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QTextBlockUserData_shell
void __qt_destruct_QTextBlockUserData(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTextBlockUserData")
    reinterpret_cast<QTextBlockUserData_shell*>(ptr)->~QTextBlockUserData_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTextBlockUserData::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextBlockUserData_initialize_1native__Lio_qt_gui_QTextBlockUserData_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextBlockUserData::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextBlockUserData_0, sizeof(QTextBlockUserData_shell), typeid(QTextBlockUserData), true, &deleter_QTextBlockUserData, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QTextBlockUserData(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QTextBlockUserData>("QTextBlockUserData", "io/qt/gui/QTextBlockUserData");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QTextBlockUserData, {
        ConstructorInfo(&__qt_construct_QTextBlockUserData_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTextBlockUserData);
    registerSizeOfShell(typeId, sizeof(QTextBlockUserData_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QTextBlockUserData_shell.cpp <==
#include "QTextBlockUserData_shell.h"
#include <QtJambi/Cast>

void deleter_QTextBlockUserData(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTextBlockUserData")
    QTextBlockUserData *_ptr = reinterpret_cast<QTextBlockUserData *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QTextBlockUserData_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QTextBlockUserData_shell) ); }

jmethodID QTextBlockUserData_shell::__shell_javaMethod(int pos) const { return QTextBlockUserData_shell::__shell()->javaMethod(typeid(QTextBlockUserData), pos); }

// emitting (writeShellConstructor)
QTextBlockUserData_shell::QTextBlockUserData_shell()
    : QTextBlockUserData()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QTextBlockUserData::QTextBlockUserData_shell()", QTextBlockUserData_shell::__shell())
    QTextBlockUserData_shell::__shell()->constructed(typeid(QTextBlockUserData));
}

// emitting (writeShellDestructor)
QTextBlockUserData_shell::~QTextBlockUserData_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QTextBlockUserData::~QTextBlockUserData()", QTextBlockUserData_shell::__shell())
    QTextBlockUserData_shell::__shell()->destructed(typeid(QTextBlockUserData));
}

void QTextBlockUserData_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QTextBlockUserData_shell*>(ptr)->QTextBlockUserData_shell::__shell()->tryDeleteShell(typeid(QTextBlockUserData));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QTextBlockUserData()
void __qt_construct_QTextBlockUserData(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTextBlockUserData()")
    Q_UNUSED(__java_arguments)
    QTextBlockUserData *__qt_this = new(__qtjambi_ptr) QTextBlockUserData_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QTextBlockUserData::QTextBlockUserData()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextBlockUserData_initialize_1native__Lio_qt_gui_QTextBlockUserData_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextBlockUserData::QTextBlockUserData()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextBlockUserData, sizeof(QTextBlockUserData_shell), typeid(QTextBlockUserData), true, &deleter_QTextBlockUserData, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QTextBlockUserData_shell
void __qt_destruct_QTextBlockUserData(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTextBlockUserData")
    reinterpret_cast<QTextBlockUserData_shell*>(ptr)->~QTextBlockUserData_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QTextBlockUserData(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QTextBlockUserData>("QTextBlockUserData", "io/qt/gui/QTextBlockUserData");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QTextBlockUserData, {
        ConstructorInfo(&__qt_construct_QTextBlockUserData, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTextBlockUserData);
    registerSizeOfShell(typeId, sizeof(QTextBlockUserData_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
